@@ -1,7 +1,6 @@
 from __future__ import annotations
-from typing import List, Union, Callable, TypeVar, Any
+from typing import List, Union, Callable, TypeVar, Any, Generic, Optional
 import datetime
-import re
 import functools
 import logging
 from .. import configuration
@@ -125,7 +124,12 @@ class ThreeCommasParser:
         return decorator
 
 
-class OfDictClass(dict):
+class ThreeCommasDict(dict):
+    def __init__(self, d: dict = None):
+        if d is None:
+            return
+        super().__init__(d)
+
     @classmethod
     def of(cls, d: dict) -> Union[None, cls]:
         if d is None:
@@ -133,58 +137,50 @@ class OfDictClass(dict):
         return cls(d)
 
     @classmethod
-    def of_list(cls, list_of_d: List[dict]) -> Union[None, List[cls]]:
+    def of_list(cls, list_of_d: List[dict]) -> List[cls]:
         if list_of_d is None:
             return None
-        return [cls.of(d) for d in list_of_d]
+        return [cls(d) for d in list_of_d]
 
     def __repr__(self):
         return f'{self.__class__.__name__}({super().__repr__()})'
 
 
-class BotEvent(OfDictClass):
-    PRICE_PATTERN = re.compile(r"Price: ([\d.]+)\b", re.IGNORECASE)
-    SIZE_PATTERN = re.compile(r"Size: ([\d.]+)\b", re.IGNORECASE)
-    QUOTE_CURRENCY_PATTERN = re.compile(r"Price: [\d.]+ (\w+).", re.IGNORECASE)
-    BASE_CURRENCY_PATTERN = re.compile(r"\([\d.]+ (\w+)\)", re.IGNORECASE)
-    SAFETY_TRADE_EXECUTED_PATTERN = re.compile(r"Safety trade \(\d+ out of \d+\) executed", re.IGNORECASE)
-    SAFETY_TRADE_NR_PATTERN = re.compile(r"Safety trade \((\d+) out of \d+\) executed", re.IGNORECASE)
+class ThreeCommasModel(ThreeCommasDict):
+    def __getattr__(self, name):
+        proxy_type = self.__class__.parsing_map.get(name)
+        if proxy_type is QuestionMarkProxy:
+            return self.get(name + '?')
+        item = self.get(name)
+        if item is None:
+            return None
+        if proxy_type is None:
+            return item
+        try:
+            return proxy_type(item)
+        except ValueError:
+            return item
 
-    @ThreeCommasParser.parsed_timestamp
-    def get_created_at(self) -> Union[None, str, datetime.datetime]:
-        return self.get('created_at')
+    def __setattr__(self, key, value):
+        self[key] = value
 
-    def get_message(self) -> str:
-        return self.get('message')
 
-    def is_base_order_executed_message(self):
-        return 'Base order executed' in self.get_message()
+class StrIntProxy(int):
+    def parsed(self, parsed: bool) -> Union[str, int]:
+        return self if parsed else str(self)
 
-    def is_error(self):
-        return 'error occurred' in self.get_message()
 
-    def is_deal_completed_message(self):
-        return 'Deal completed' in self.get_message()
+class StrFloatProxy(float):
+    def parsed(self, parsed: bool) -> Union[str, float]:
+        return self if parsed else str(self)
 
-    def is_safety_trade_executed_message(self):
-        return len(self.SAFETY_TRADE_EXECUTED_PATTERN.findall(self.get_message())) > 0
 
-    def get_safety_trade_number(self):
-        findall = self.SAFETY_TRADE_NR_PATTERN.findall(self.get_message())
-        return findall[0] if findall else None
+class StrDatetimeProxy(str):
+    DATETIME_PATTERN = '%Y-%m-%dT%H:%M:%S.%fZ'
 
-    def get_price(self):
-        findall = self.PRICE_PATTERN.findall(self.get_message())
-        return findall[0] if findall else None
+    def parsed(self, parsed: bool) -> Union[str, datetime]:
+        return datetime.datetime.strptime(self, StrDatetimeProxy.DATETIME_PATTERN) if parsed else self
 
-    def get_size(self):
-        findall = self.SIZE_PATTERN.findall(self.get_message())
-        return findall[0] if findall else None
 
-    def get_quote_currency(self):
-        findall = self.QUOTE_CURRENCY_PATTERN.findall(self.get_message())
-        return findall[0] if findall else None
-
-    def get_base_currency(self):
-        findall = self.BASE_CURRENCY_PATTERN.findall(self.get_message())
-        return findall[0] if findall else None
+class QuestionMarkProxy:
+    pass
